==> grommet-2.10.0.tgz: package/components/Carousel/stories/Simple.js <==
"use strict";

var _react = _interopRequireDefault(require("react"));

var _react2 = require("@storybook/react");

var _grommetIcons = require("grommet-icons");

var _grommet = require("grommet");

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { "default": obj }; }

function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }

function _objectWithoutPropertiesLoose(source, excluded) { if (source == null) return {}; var target = {}; var sourceKeys = Object.keys(source); var key, i; for (i = 0; i < sourceKeys.length; i++) { key = sourceKeys[i]; if (excluded.indexOf(key) >= 0) continue; target[key] = source[key]; } return target; }

var SimpleCarousel = function SimpleCarousel(_ref) {
  var initialChild = _ref.initialChild,
      props = _objectWithoutPropertiesLoose(_ref, ["initialChild"]);

  return _react["default"].createElement(_grommet.Grommet, null, _react["default"].createElement(_grommet.Box, {
    align: "center",
    pad: "large"
  }, _react["default"].createElement(_grommet.Carousel, _extends({
    initialChild: initialChild
  }, props), _react["default"].createElement(_grommet.Box, {
    pad: "xlarge",
    background: "accent-1"
  }, _react["default"].createElement(_grommetIcons.Attraction, {
    size: "xlarge"
  })), _react["default"].createElement(_grommet.Box, {
    pad: "xlarge",
    background: "accent-2"
  }, _react["default"].createElement(_grommetIcons.TreeOption, {
    size: "xlarge"
  })), _react["default"].createElement(_grommet.Box, {
    pad: "xlarge",
    background: "accent-3"
  }, _react["default"].createElement(_grommetIcons.Car, {
    size: "xlarge"
  })))));
};

(0, _react2.storiesOf)('Carousel', module).add('Simple', function () {
  return _react["default"].createElement(SimpleCarousel, null);
}).add('Initial Child', function () {
  return _react["default"].createElement(SimpleCarousel, {
    initialChild: 1
  });
}).add('Without Controls', function () {
  return _react["default"].createElement(SimpleCarousel, {
    controls: false,
    play: 1500
  });
});

==> grommet-2.14.0.tgz: package/components/Carousel/stories/Simple.js <==
"use strict";

var _react = _interopRequireDefault(require("react"));

var _react2 = require("@storybook/react");

var _grommetIcons = require("grommet-icons");

var _grommet = require("grommet");

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { "default": obj }; }

function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }

function _objectWithoutPropertiesLoose(source, excluded) { if (source == null) return {}; var target = {}; var sourceKeys = Object.keys(source); var key, i; for (i = 0; i < sourceKeys.length; i++) { key = sourceKeys[i]; if (excluded.indexOf(key) >= 0) continue; target[key] = source[key]; } return target; }

var SimpleCarousel = function SimpleCarousel(_ref) {
  var initialChild = _ref.initialChild,
      props = _objectWithoutPropertiesLoose(_ref, ["initialChild"]);

  return /*#__PURE__*/_react["default"].createElement(_grommet.Grommet, null, /*#__PURE__*/_react["default"].createElement(_grommet.Box, {
    align: "center",
    pad: "large"
  }, /*#__PURE__*/_react["default"].createElement(_grommet.Carousel, _extends({
    initialChild: initialChild
  }, props), /*#__PURE__*/_react["default"].createElement(_grommet.Box, {
    pad: "xlarge",
    background: "accent-1"
  }, /*#__PURE__*/_react["default"].createElement(_grommetIcons.Attraction, {
    size: "xlarge"
  })), /*#__PURE__*/_react["default"].createElement(_grommet.Box, {
    pad: "xlarge",
    background: "accent-2"
  }, /*#__PURE__*/_react["default"].createElement(_grommetIcons.TreeOption, {
    size: "xlarge"
  })), /*#__PURE__*/_react["default"].createElement(_grommet.Box, {
    pad: "xlarge",
    background: "accent-3"
  }, /*#__PURE__*/_react["default"].createElement(_grommetIcons.Car, {
    size: "xlarge"
  })))));
};

(0, _react2.storiesOf)('Carousel', module).add('Simple', function () {
  return /*#__PURE__*/_react["default"].createElement(SimpleCarousel, null);
}).add('Initial Child', function () {
  return /*#__PURE__*/_react["default"].createElement(SimpleCarousel, {
    initialChild: 1
  });
}).add('Without Controls', function () {
  return /*#__PURE__*/_react["default"].createElement(SimpleCarousel, {
    controls: false,
    play: 1500
  });
});
